# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Systemd
# https://github.com/systemd/systemd/blob/42911a567dc22c3115fb3ee3c56a7dcfb034f102/src/core/macros.systemd.in

# "If your package includes one or more systemd units that need
# to be enabled by default on package installation,
# they must be covered by the Fedora preset policy."

Name:           systemd-cron
Version:        2.5.1
Release:        %{autorelease}
License:        MIT
Summary:        systemd generator to provide cron daemon & anacron functionality
Url:            https://github.com/systemd-cron/systemd-cron/
Source0:        https://github.com/systemd-cron/systemd-cron/archive/v%{version}.tar.gz
Provides:       cronie
Provides:       cronie-anacron
Conflicts:      cronie
Conflicts:      cronie-anacron
Requires:       crontabs
Requires:       systemd
BuildRequires:  g++
BuildRequires:  libmd-devel

%description
Provides a systemd generator to run cron jobs in /etc/cron.hourly cron.daily cron.weekly and cron.monthly directories, crontab etc..
without having cron or anacron installed.

%pre
# Prevent execution of boot and reboot scripts on installation
touch /run/crond.reboot
touch /run/crond.bootdir
# /etc/cron.boot isn't on fedora,
# but we're enabling support for it anyways.

%preun
%systemd_preun cron.target

%post
# XXX this macro doesn't seems to do anything
%systemd_post cron.target
if [ $1 -eq 1 ] ; then
        systemctl daemon-reload
        systemctl enable cron.target
        systemctl start cron.target
fi
systemctl reload-or-restart systemd-sysusers.service systemd-tmpfiles-setup.service

%postun
%systemd_postun_with_restart cron.target

%prep
%setup -q

%build
./configure \
  --enable-runparts=no \
  --enable-minutely=yes \
  --enable-quarterly=yes \
  --enable-semi_annually=yes \
  --enable-boot=yes

# Disabled run-parts i.e. static single units for each granuarity level.
# Instead opting to use only systemd-generators
# run-parts override the generator when installed
# Also enabled all disabled granularity levels
# cron.boot isn't supported in fedora,
# But we enable it anyway for those who want it.

# Compile
%make_build

%install
# Install
export RPM_BUILD_ROOT
make DESTDIR=${RPM_BUILD_ROOT} install

# Required directories
mkdir -p $RPM_BUILD_ROOT/etc/cron.d/

# Cleanup cronjob not included as systemd timer for it exists.
# mkdir -p $RPM_BUILD_ROOT/etc/cron.weekly/
# cp contrib/systemd-cron.cron.weekly $RPM_BUILD_ROOT/etc/cron.weekly/systemd-cron

# Systemd preset policy
mkdir -p $RPM_BUILD_ROOT/usr/lib/systemd/system-preset/
echo 'enable cron.target' > $RPM_BUILD_ROOT/usr/lib/systemd/system-preset/50-systemd-cron.preset

# Appropriate grouping;
# This is fedora-specific as in other distros it is handled by a common package,
# Needed for /var/spool/cron
echo 'g crontab - -' >> ${RPM_BUILD_ROOT}/usr/lib/sysusers.d/systemd-cron.conf

# Preparing /var/spool/cron using tmpfiles.d
mkdir -p ${RPM_BUILD_ROOT}/usr/lib/tmpfiles.d
touch ${RPM_BUILD_ROOT}/usr/lib/tmpfiles.d/systemd-cron.conf
echo 'd /var/spool/cron 1730 root crontab' >> ${RPM_BUILD_ROOT}/usr/lib/tmpfiles.d/systemd-cron.conf
# /var/spool/cron not included in package as tmpfiles handles it
# Needs to be in `crontabs` package for cross-cron-implementation compatibility

# setgid helper
chmod g+s $RPM_BUILD_ROOT/usr/libexec/systemd-cron/crontab_setgid
# Licensing
cp LICENSE COPYING

%files
%license LICENSE
%doc README.md CHANGELOG COPYING
%dir /etc/cron.d/
%dir /usr/libexec/systemd-cron

/usr/bin/crontab
/usr/libexec/systemd-cron/mail_for_job
/usr/libexec/systemd-cron/boot_delay
/usr/libexec/systemd-cron/remove_stale_stamps
/usr/libexec/systemd-cron/crontab_setgid
/usr/lib/systemd/system-generators/systemd-crontab-generator

/usr/lib/systemd/system-preset/50-systemd-cron.preset
/usr/lib/systemd/system/cron.target
/usr/lib/systemd/system/cron-update.path
/usr/lib/systemd/system/cron-update.service
/usr/lib/systemd/system/cron-mail@.service
/usr/lib/systemd/system/systemd-cron-cleaner.service
/usr/lib/systemd/system/systemd-cron-cleaner.timer
/usr/lib/sysusers.d/systemd-cron.conf
/usr/lib/tmpfiles.d/systemd-cron.conf

%{_mandir}/man1/crontab.*
%{_mandir}/man5/crontab.*
%{_mandir}/man5/anacrontab.*
%{_mandir}/man7/systemd.cron.*
%{_mandir}/man8/systemd-crontab-generator.*
